

set -ex



git clone https://github.com/HypothesisWorks/hypothesis.git src
cd src/hypothesis-python
python -m pytest -n 0  tests/cover
python -m pytest -n 0  tests/datetime
python -m pytest -n 0  tests/fakefactory
python -m pytest -n 0  tests/numpy
python -m pytest -n 0  tests/pandas
python -m pytest -n 0  tests/py3
python -m pytest -n 0  tests/pytest -p pytester --runpytest subprocess
exit 0
